bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 16. Aventiure
___________________________________________________ #### Auentv wie Sivrit ermort wart
| ### Gvnther> vn– Hagene die rechen vil balt ### lobten mit vntriwen ein pirsen in den walt ### mit ir scharpfen geren si wolden iagn swin ### pern vn– wisende waz mohte kuners gesin ### Da mite reit ovch Sivrit in vrolichem site ### herrenliche spise die fvrte man in mite ### zeinem kalten brunnen namens im den lip ### daz het geraten Prunh' des kunic Guntheres wip
###### 926 | ### Do gie der degene chvne da er Chriemh' vant ### ez was nv vf gesvomet sin edel pirsgewant ### vn– ander der gesellen si wolden vber Rin ### done dorfte Chriemh' leider nimmer gesin
| ### Die sinen trvtinne die chuster an den mvnt ### got laze mich dich frowe gesehn noch gesvnt ### vn– mich div dinen ovgen mit holden magen din ### soltv kurcewilen ine mac hie heime niht gesin
###### 928 | ### Do gedahtes an div mære sine torst ir niht gesagen ### da von si Hagen <e> vragte do begunde klagen ### div edele kuniginne daz si ie gewan den lip ### do weinte ane maze des kunen Sivrides wip
###### 929 | ### Si sprach zv dem rechen lat iwer iagen sin ### mir trovmte hinte leide wie ivch zwei wildiv swin ### iagent vber heide da wrden blvmen rot ### daz ich so sere weine daz tvot mir armem wibe not
###### 930 | ### Ja fvrhte ich herre Sivrit eteslichen rat ### ob man der deheinen missedie[35v]net hat ### die vns gefvgen chunnen <eteslichen> haz ### belibet herre Sivrit mit triwen rate ich iv daz
| ### Er sprach liebiv frowe ich chum in kurcen tagn ### ine weiz hie niht der uinde die vns iht hazzes tragen ### alle dine mage sint mir gemeine holt ### ovch enhan ich an den degenen hie niht anders verscholt
###### 932 | ### Neyna herre Sivrit ia vurht ich dinen val ### mir trovmte hinte leide wie ob dir zetal ### vielen zwene berge ich ensach dich nimmer me ### wiltv nv mir scheiden daz tvot mir <inneklichen> we
###### 933 | ### Er vmbevie mit armen daz tugende riche wip ### mie minneklichem chussen trvot er ir schonen lip ### mit vrlovbe er <dannen> schiet in churcer stunt ### sine gesach in leider darnach nimmer mer gesvnt
| ### Do riten si von dannen in einen walt ### durch kurcewile willen vil manic degen balt ### riten mit dem wirte man fvrt ovch mit in dan ### vil der edeln spise die di helede solden han
###### 935 | ### Geladen vil der rosse chom vor in vber Rin ### die den iegeren trvgen brot un– win ### vleisc vn– uische vn– anders manigen rat ### den ein kvnic so <riche> harte billechin hat
###### 936 | ### Si hiezen herbergen fvr den grunen walt ### da si da iagn solden ### vf einen wert vil breit ### do chom der herre Sivrit daz wart dem kunige geseit
###### 937 | ### Von dem iagtgesellen wrden gar bestan ### die warte an allen enden do sprach der chune man ### Sivrit der starche wer sol vns durch den walt ### wisen vor den bergen ir rechen chven vn– balt
| ### Ia mvzen wir vns scheiden sprach do Hagene ### e daz wir beginnen hie ze iagene ### da bi wir bechennen ich un– der herre min ### wer <die> besten iægere an dirre waltreise sin
###### 939 | ### Lvot vn– ovch gehvende wir suln teilen gar ### so cher ieslicher swar er gerne var ### der danne iage daz beste des sage man im danch ### do wart ir biten niht zen herbergen lanch
###### 940 | ### Do sprach der herre Sivrit ich han der hvnde rat ### niwan einen brachen der so genozzen hat ### daz er die verte erchenne der tyere durch den tan ### do schvf der kunic Gunther zvo zim den er <wolde> han
###### 941 | ### Do nam er einen iæger meister einen gvten spvrhunt ### er brahte den <herren> in einer kurcen stunt ### da si vil tyere funden swaz der von legere stvnt ### die eriageten die gesellen so noh gvte iægere tunt
###### 942 | ### Swaz ir ber brache ersprancte die sluoc mit siner hant ### Sivrit der vil chvene der helt vz Niderlant ### sin ross daz livf so sere daz ir im niht entran ### daz lop an dem geiægede er vor in allen da gewan
###### 943 | ### Er was an allen dingen biderbe genvoch ### sin tyere <was> daz erste daz er ze tode sluoch ### ein vil starchez halpfwol mit der sinen hant ### dar nach er harte schiere einen grimmen lewen vant
###### 944 | ### Do der wart ersprenget den [36r]schoz er mit dem bogen ### eine scharpfe stralen het er dar in gezogen ### der lewe lief nach dem schuzze wan drier sprunge lanch ### die sinen iagtgesellen die sagten Sivride danch
| ### Darnach slvger schiere einen wisent vn– elch ### starcher vore viere un– einen grimmen schelch ### sin ross trvg in so <balde> daz ir im niht entran ### hirz oder hinden chund im wenic iht engan
###### 946 | ### Einen ebyr grozen den sach der spurehvnt ### als er begunde vliehen do chom an der stvnt ### des selben geiægedes meister der bestunt in vf der sla ### daz swin vil zornikliche lief an den chunen rechen sa
###### 947 | ### Do slvg in mit dem swerte der Chriemh' man ### ez hete ein ander iægere so sanfte niht getan ### do er in het ervellet man vie den spurehunt ### do wart sin iagt daz riche wol den Buregonden kunt
###### 948 | ### Do sprachen sine iægere magez mit hulden wesn ### so lat uns herre Sivrit der tyer ein teil genesn ### ir tvot uns <hivte> lære den berch un– ovch den walt ### des begunde smielen der degn chune vn– balt
| ### Do hortens allenthalben lvdem un– doz ### von lvten vn– ovch von hunden der schal was so groz ### daz in da von antwrte berge vn– ovch der tan ### vier vn– drizzech rvore die iægere heten verlan
###### 950 | ### Do mvse vil der tyere verliesen da daz lebn ### do wanden si <daz> fvegen daz man in mvste geben ### den pris an dem geiægede des enchunde niht geschehn ### do der starche Sivrit wart zer viwerstete gesehn
###### 951 | ### Daz pirsen was ergangen vn– idoch niht gar ### die zem viwer wolden di brahten mit in dar ### vil maniger hande tyere vn– wildes genvoch ### hey waz man des zer chuchen des kuniges ingesinde trvoch
| ### Do hiez der kunic kuonden den iægern voz erchorn ### daz er enbizen wolde do wart vil lvot ein horn ### zeiner stunt geblasen da mit in wart erchant ### daz man den fursten edele da zen herbergen vant
###### 953 | ### Ein Sivrides iægere sprach ich han vernomen ### von eines hornes duzze daz wir nv suln chomen ### zv den herbergen antwrten ich des wil ### do wart nach den iægeren gevraget blasende vil
###### 954 | ### Do sprach der herre Sivrit nv rvomen ovch wir den tan ### sin ros daz truogin ebene si ilten mit im dan ### si ersprancten mit ir scalle ein tyer vil gremilich ### daz was ein ber wilde do sprach der degn hinder sich
###### 955 | ### Welt ir uns hergesellen kurcewile wern ### den brachen sult ir lazen ia sih ich einen bern ### der sol zen herbergen mit uns hinnen varn ### swie vbel er gebare ern chan sihs nimmer bewarn
| ### Der brache wart verlazen der ber spranch von dan ### do <wolde> in erriten der Chriemh' man ### er chom in ein gevelle done chundes niht wesn ### daz starche tyer do wande vor dem iægere genesn
###### 957 | ### Do spranch von sinem [36v]rosse der stolze ritter gvot ### er begunde laufen sere daz tyere was vnbehvot ### ez enchunde im niht entrinnen do vienger ez zehant ### ane aller slahte wnden der helt ez schiere gebant
###### 958 | ### Chrazzen noch gebizen chundez niht den man ### er bandez zvo dem satele gewalteklichen dan ### braht erz an die fivrstat durch sinen hohen mvot ### zeiner kurcewile der reche kvene vn– gvot
###### 959 | ### Wie rehte weigerliche er zen herbergen reit ### sin gere was vil michel starch vn– breit ### im hienge en–n starchez waffen nider an den sporn ### von vil rotem golde fvrter ein herlichez horn
| ### Von bezzerm birsgewæte gehort ir nie gesagen ### einen roch von swarzem pfellel den sah man in tragen ### un– einen hvot von zobele der riche was genvoch ### hey waz er gvter porten an sinem chochære trvoch
###### 961 | ### Ein hvot von einem pantel dar vber was gezogn ### durch richeite vn– durch sveze ovch fvrter einen bogn ### den man ziehen mvse mit antwerche dan ### der in spannen solde ern hete iz selbe getan
###### 962 | ### Von einer lvdemes hvte was allez sin gewant ### von hovpte vnz an daz ende gestrvete man drvfe vant ### vz der liehten rvhe vil manic goldes zein ### ze beiden sinen siten <dem> kuonin iægermeister schein
###### 963 | ### Ovch furter Palmvngen ein ziere wafen breit ### so starch un– ovch so scherpfe wie vreislich ez sneit ### swa man ez slvoch vf helme sin ecke warn gvot ### der hereliche iægere der was vil hohgemvot
| ### Sit daz ich ivch der mære gar bescheiden sol ### im was sin gvot chocher vil gvoter stralen vol ### mit guldinnen tullen div sahs wol spannen breit ### ez mvse bald ersterbn swaz er mit schiezen versneit
###### 965 | ### Do reit der ritter edele vil weidenlichen dan ### in sahen zvo zin chumende die Guntheres man ### si liefen im engegene vn– enpfiengen im daz march ### do fvrter bi dem satele einen bern groz vn– starch
###### 966 | ### Als er gestvnt von rosse do loster im div bant ### von fvezen vnt von munde do erlutte da zehant ### vil groze daz gehunde swaz des den bern sach ### daz tyer ze walde wolde die lvte heten vngemach
###### 967 | ### Der ber von <dem> schalle durch die chvchen geriet ### hey waz er chuchenknehte von dem fivre schiet ### vil chezzil wart gervret zerfvret manic brant ### hey waz man gvter spise in der aschen ligen vant
| ### Do sprungen von dem sedele die herren vn– ir man ### der ber begunde zvrnen der kunic hiez do lan ### allez daz gehunde daz an seilen lach ### wær iz wol verendet si heten vrolichen tach
###### 969 | ### Mit bogen vn– mit spiezen niht langer man daz lie ### do liefen dar die snellen da der ber gie ### so vil was der hvnde daz da niemen schoz ### von dem <gro> [37r]schalle beidiv berch vn– walt erdoz
###### 970 | ### Der ber begunde vliehen vor den hunden dan ### im enchunde niht gevolgen wan Chriemh' man ### der erliefen mit <dem> swerte ze tode er in do slvoch ### hin wider zv der chuochen man den bern sider trvoch
| ### Do sprachen die daz sahen er wær ein chreftic man ### die stolzen iagtgesellen hiez man zen tischen gan ### vf einen schonen anger saz ir da genvoc ### waz man do richer spise den iagtgesellen dar trvoc
###### 972 | ### Die schenchen chomen seine die tragen solden win ### ez enchunde baz gedienet nimmer heleden sin ### heten si dar vnder niht so valschen mvot ### so wæren wol die degene vor allen schanden behvot
###### 973 | ### Done hete nilnt der sinne der chuene veige man ### daz er sich ir untriwe chunde han verstan ### er was in ganzen tugenden alles <valsches> bloz ### sins sterbes mvose engelten sit der sin nie niht genoz
###### 974 | ### Do sprach der herre Sivrit wnder mich des hat ### sit man vns von der chuchen git so manigen rat ### durch waz uns die schenchen bringen niht den win ### man enpflege baz der iægere ine wil niht iagtgeselle sin
###### 975 | ### Ich hete wol gedienet daz man min næme war ### der chunic ob dem tische sprach in valsche dar ### man solz iv gerne bvzen swes wir gebresten han ### wir sin von Hagene schulde hivt ane trinchen bestan
| ### Do sprach der von Tronege vil lieber herre min ### ich wande daz diz pirsen hivte solde sin ### da zem Spehtsharte den win den sande ich dar ### sin wir hie vngetrunchen wie wol ihz immer mer bewar
###### 977 | ### Do sprach der herre Sivrit ir lip der habe vndanc ### man solde mir siben savme win un– luttertranc ### habn her gefveret do des niht mohte sin ### do solde man vns naher han gesidelt an den Rin
###### 978 | ### Do sprach aber Hagene ir edeln ritter balt ### ich weiz hie vil nahen einen brunnen der ist chalt ### daz ir niht enzvrnet da svln wir hine gan ### der rat wart manigem degene ze grozen sorgen getan
###### 979 | ### Den helt von Niderlanden dwanch des durstes not ### den tische er deste ziter rvchen dan gebot ### er wolde fvr die berge zv dem brunnen gan ### do was der rat mit meine von den degenen getan
###### 980 | ### Div tyer man hiez vf wægenen fveren in daz lant ### div da verhowen hete div Sivrides hant ### man iah im grozer eren swer ez ie gesach ### Gunther sine triwe vaste an Sivride brach
| ### Do si dannen wolden zvo der linden breit ### do sprach aber Hagene mir ist dicke daz geseit ### daz niht gevolgen chunne dem Chriemh' man ### swenner wolde gahen hey wolde vns daz sehn lan
###### 982 | ### Do sprach von Niderlanden der herre Sivrit ### ir mvgt ez wol <versvchen> welt ir mir lovfen mite ### ze wette zv dem brunnen so daz si getan ### der sol han [37v]gewnnen den man siht ze vorderst stan
###### 983 | ### Nv welle ovch wirz versvochen sprach Hagene der degn ### do sprach der starche Sivrit so wil ich mich legn ### fvr die iwern fveze nider an daz gras ### do Gunther daz gehorte hey wie lieb im daz was
###### 984 | ### Do sprach der degn chvne ich wil iv mære sagn ### allez min gewæte wil ich an mir tragn ### den ger zv dem schilte vn– al min pirsgewant ### den chocher zvo dem swerte vil schier er vmbe gebant
| ### Do zvgen si div chleider von dem libe dan ### in zwein wizen hemeden sach man si beide stan ### sam zwei wildiv pantel si liefen durch dcn kle ### doch sah man bi dem brunnen den snellen Sivriden ê
###### 986 | ### Den pris an allen dingen trvger vor manigem man ### daz swert er loste balde den chocher leit er dan ### sinen ger den starchen leinter an der linden ast ### bi des prunnen vlvozze stunt der herliche gast
###### 987 | ### Di Sivrides tugende warn harte groz ### den schilt leit er nidere al da der brunne vloz ### swie harte so in durste der helt doch niene tranch ### e daz der kunic choeme daz dvhte Sivriden lanch
###### 988 | ### Der brunne was vil chvele lutter un– gvot ### Gunther sich do legete nider zv der flvot ### daz wazzer mit dem munde er von der flvote nam ### si gedahten daz ovch Sivrit nach im mvese tvon alsam
| ### Do engalt er siner zvehte den bogen vn– daz swert ### daz trvog allez Hagene von im dane wert ### do spranger hin widere da er den ger da vant ### er sach nach eime cruce an des kuniges gewant
###### 990 | ### Da der herre Sivrit ob dem brunnen tranch ### er schoz <in> durch daz chruce daz vz der wnden spranc ### daz blvt im von dem hercen an die Hagenen wat ### so groze missewende ein helt nv nimmer mer begat
###### 991 | ### Den ger gegen dem hercen stechen er im lie ### also angestlichen ze flvhten Hagene nie ### gelief noch in der werlde vor decheinem man ### do sich der herre Sivrit der starchen wnden versan
###### 992 | ### der reche tobliche von dem brunnen spranch ### im ragete von dem hercen ein gerstange lanch ### der fvrste wande vinden bogen oder swert ### so mvse wesn Hagene nach sime dienste gewert
| ### Do der sere wnde des swertes niht envant ### done het et er niht mere wan des schildes rant ### den zvhter von dem brunnen do lief er Hagenen an ### done chunde im niht entrinnen der vil vngetriwe man
###### 994 | ### Swie wnt er was zem tode so chrefteklich er slvoc ### daz vzer dem schilde dræte genvoc ### des edeln gesteines der schilt vil gar zebrast ### sich hete gerne errochen der vil herlich gast
###### 995 | ### Hagene mvse vallen von siner hant zetal ### von des slages chrefte der wert vil lvte erhal ### het er daz swert enhende so wær ez Hagenen tot ### der helt en[38r]tran vil chvme vz der <angestlichen> not
###### 996 | ### Sin chraft was im geswichen ern kunde niht gestan ### sines libes sterche div mvse gar zergan ### wander des todes zeichen bi liehter varwe truoc ### sit wart er beweinet von schoenen vrowen genvoc
###### 997 | ### Do uiel in die blvomen der Chriemh' man ### daz blvot von sinen wnden sach man vaste gan ### do begvnder schelten des twanch in michel not ### die vfin geraten heten den ungetriwen tot
| ### Do sprach der sere wnde ia ir vil bose zagn ### waz hilfet mich min dienest daz ir mich habt erslagen ### ich was <iv> ie getriwe des ich engolten han ### ir habt an iwern magen leider vbel getan
###### 999 | ### Die sint da von bescholten swaz ir wirt geborn ### her nach disen ziten ia habt ir iwern zorn ### vil vbele gerochen an dem libe min ### mit laster ir gescheiden svlt von gvten <rechen> sin
###### 1000 | ### Die lvte liefen alle da er reslagen lac ### ez was ir genvgen ein frevdeloser tac ### die iht triwe heten von den wart er bekleit ### daz het wol gedienet der ritter chn vn– gemeit
###### 1001 | ### Der kunic von Burgonden klagete sinen tot ### do sprach der verchwnde daz ist ane not ### daz der nach schaden weinet der in da hat getan ### der dienit michel schelten ez wære bezzer verlan
###### 1002 | ### Do sprach der grimme Hagene iane weiz ich waz er kleit ### ez hat nv allez ende vnser sorge vn– vnser leit ### wir vinden ir vil kleine die turren vns bestan ### wol mich deich siner herschaft han ze rate getan
###### 1003 | ### Ir mvgt ivch lihte rvemen sprach do Sivrit ### het ich an iv erchennet den mortlichen sit ### ich hete wol behalten vor iv minen lip ### mich enriwet niht so sere so froe Chriemh' min wip
###### 1004 | ### Nv mvze got erbarnnen deich ie gewan den <svn> ### dem solch itewizen sol nach den ziten tvon ### daz siner mage iemen mit morde habn erslagn ### moht ich so sprach Sivrit daz solt ich billiche klagn
###### 1005 | ### Zer werlde wart nie mere grozer mort began ### sprach er zvo dem kunige denne an mir ist getan ### ich behielt iv lib vn– ere in angestlicher not ### ich hans engolten sere daz ihz iv ie so wol erbot
###### 1006 | ### Do sprach vil seneliche der verchwnde man ### welt ir kunic riche triwen iht began ### in der werlt an iemen lat iv bevolhen sin ### vf triwe un– vf genade di lieben truttinne min
###### 1007 | ### Vn– lat si des geniezen daz si iv swester si ### durch aller fursten tvgende wont ir mit triwen bi ### mir mvzen warten lange min vater vn– mine man ### ez enwart nie frowen mere an frivnde leider getan
| ### Er rampf sich bitterliche als im div not gebot ### vn– sprach do iæmirliche der mortlich tot ### mag ivch wol geriwen her nach disen tagen ### gelovbt [38v]an rehten triwen daz ir ivch selben habt erslagn
###### 1009 | ### Die blumen allenthalben von blvote warn naz ### do ranger mit dem tode vnlange tet er daz ### wande in des todes wafen al ze sere sneit ### do mohte reden niht mere der reche chven un– gemeit
###### 1010 | ### Do die herren sahen daz der helt was tot ### si leiten in vf einen schilt der was von golde rot ### vn– wrden des ze rate wie daz solde ergan ### daz man iz verhêle daz iz het Hagene getan
| ### Do sprachen ir genvoge vns ist vbele geschehn ### ir sult ez heln alle vn– svlt geliche iehn ### da er rite iagn eine der Chriemh' man ### in slvgen schachære da er fvre durch den tan
###### 1012 | ### Do sprach der ungetriwe ich fvren n–n daz lant ### mir ist vil vnmære vn– wirt ez ir bechant ### div so hat getrubet miner frowen mvot ### ez ahtet mih vil ringe swaz si weinens getvot
###### 1013 | ### Von dem selben brunnen da Sivrit wart erslagen ### sult ir div rehten mære von mir hoern sagn ### vor dem Otenwalde ein dorf lit Otenhaim ### da vliuzet noch der brunne des ist zwifel dehein

<<< Übersicht <<< vorige Seite nächste Seite >>>